#ifndef _OcclusionQuery_H__
#define _OcclusionQuery_H__

#include <vector>
#include "common.h"


namespace CHCDemo 
{ 

class BvhNode;

/** This class is an implementation for single node queries and multiqueries.
	@remark the class encapsulates hardware occlusion query calls.
*/
class OcclusionQuery
{
public:
	
	OcclusionQuery();

	virtual ~OcclusionQuery();

	virtual bool ResultAvailable() const;
	
	virtual unsigned int GetQueryResult() const;
	
	virtual void BeginQuery();
	
	virtual void EndQuery();
	
	unsigned int GetQueryId() const;
	/** Returns the first added node.
	*/
	inline BvhNode *GetFrontNode() const { return mNodes[0]; }
	/** Reset the contents of this query.
	*/
	inline void Reset() { mNodes.clear(); }
	/** Adds a node to the query.
	*/
	inline void AddNode(BvhNode *node) { mNodes.push_back(node); }


protected:

	OcclusionQuery(unsigned int id);
	
	
	////////////
	//-- members

	float mPFail;
	/// all nodes that are tested with the same query
	BvhNodeContainer mNodes; 
	// the query associated with this test
	unsigned int mQueryId;
	/// type of the query
	bool mIsVisibleQuery;
};

} // namespace 
#endif // OcclusionQuery_H